@@ -15,6 +15,8 @@ USERS_ME_URL = BASE_URL + "users/me/"
 DEVICES_URL = BASE_URL + "devices/"
 DEVICE_URL = DEVICES_URL + "$DEVID$/"
 DEVICE_ACTIVITIES_URL = DEVICE_URL + "activities/"
+DEVICE_ACTIVITY_URL = DEVICE_ACTIVITIES_URL + "$ACTID$/"
+DEVICE_ACTIVITY_VIDEO_URL = DEVICE_ACTIVITY_URL + "video/"
 DEVICE_AVATAR_URL = DEVICE_URL + "avatar/"
 DEVICE_INFO_URL = DEVICE_URL + "info/"
 DEVICE_SETTINGS_URL = DEVICE_URL + "settings/"
@@ -41,6 +43,13 @@ CLIENT_ID = "client_id"
 DEVICES = "devices"
 TOKEN = "token"
 
+# ATTRIBUTES
+ATTR_LAST_CHECK_IN = "last_check_in"
+ATTR_WIFI_SSID = "wifi_ssid"
+ATTR_WIFI_STATUS = "wifi_status"
+
+ATTR_OWNER_STATS = [ATTR_LAST_CHECK_IN, ATTR_WIFI_SSID, ATTR_WIFI_STATUS]
+
 # DEVICE
 ACL = "acl"
 ACTIVITY = "activity"
@@ -129,6 +138,3 @@ VIDEO_PROFILE_VALUES = [
 LED_VALUES = [0, 255]
 
 BRIGHTNESS_VALUES = [0, 100]
-
-EventType = dict[str, dict[str, str]]
-DeviceType = dict[str, dict[str, dict[str, str]]]
